@@ -1,6 +1,6 @@
 from extras.plugins import PluginConfig
 
-__version__ = "0.0.0.0.59"
+__version__ = "0.0.0.0.91"
 
 
 class OCPProjectConfig(PluginConfig):
@@ -11,7 +11,19 @@ class OCPProjectConfig(PluginConfig):
     version = __version__
     author = "Tim Rhomberg"
     author_email = "timrhomberg@hotmail.com"
-    required_settings = ["gitlab_project_url", "values_path", "default_access_token"]
+    required_settings = [
+        "gitlab_project_url",
+        "values_path",
+        "default_access_token",
+        'jira_browse_url',
+        'ocp_tst_url',
+        'ocp_dev_url',
+        'ocp_int_url',
+        'ocp_prd_url',
+        'cpu_cost',
+        'memory_cost',
+        'storage_cost'
+    ]
     base_url = "ocp-project-plugin"
 
 
