@@ -1,6 +1,6 @@
 from django.forms import (
     CharField,
-    BooleanField,
+    BooleanField, PasswordInput,
 )
 
 from netbox.forms import (
@@ -41,6 +41,10 @@ class AppEnvironmentForm(NetBoxModelForm):
                   "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
                   "limits_memory"]
 
+        widgets = {
+            'access_token': PasswordInput(),
+        }
+
 
 class AppEnvironmentFilterForm(NetBoxModelFilterSetForm):
     """Form for filtering App Environment instances."""
