@@ -1,5 +1,6 @@
 from django.db import migrations, models
 import utilities.json
+from ocp_project_plugin.fields import MemoryResourceField
 
 
 class Migration(migrations.Migration):
@@ -68,9 +69,9 @@ class Migration(migrations.Migration):
                  models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="app_env_ocp_project",
                                    to="ocp_project_plugin.OCPProject")),
                 ("requests_cpu", models.CharField(max_length=5, null=True)),
-                ("requests_memory", models.CharField(max_length=5, null=True)),
+                ("requests_memory", MemoryResourceField(null=True)),
                 ("limits_cpu", models.CharField(max_length=5, null=True)),
-                ("limits_memory", models.CharField(max_length=5, null=True)),
+                ("limits_memory", MemoryResourceField(null=True)),
             ],
             options={
                 "ordering": ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
