@@ -15,7 +15,7 @@ class AppEnvironmentTable(NetBoxTable):
     app_env = tables.Column(
         linkify=True
     )
-    mtls = tables.Column(
+    cluster_env = tables.Column(
         linkify=True
     )
     repo = tables.Column(
@@ -28,9 +28,9 @@ class AppEnvironmentTable(NetBoxTable):
     class Meta(NetBoxTable.Meta):
         model = AppEnvironment
 
-        fields = ["pk", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring",
-                  "postgres_monitoring", "ocp_project"]
+        fields = ["pk", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
+                  "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory", "limits_cpu",
+                  "limits_memory"]
 
         default_columns = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
-                           "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
-                           "requests_memory", "limits_cpu", "limits_memory"]
+                           "monitoring", "postgres_monitoring", "ocp_project"]
